@@ -1,10 +1,10 @@
 /* chgrp -- change group ownership of files
-   Copyright (C) 89, 90, 91, 1995-2006 Free Software Foundation, Inc.
+   Copyright (C) 89, 90, 91, 1995-2007 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,8 +12,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* Written by David MacKenzie <djm@gnu.ai.mit.edu>. */
 
@@ -92,7 +91,7 @@ parse_group (const char *name)
 	  unsigned long int tmp;
 	  if (! (xstrtoul (name, NULL, 10, &tmp, "") == LONGINT_OK
 		 && tmp <= GID_T_MAX))
-	    error (EXIT_FAILURE, 0, _("invalid group %s"), quote (name));
+	    error (EXIT_FAILURE, 0, _("invalid group: %s"), quote (name));
 	  gid = tmp;
 	}
       endgrent ();		/* Save a file descriptor. */
@@ -160,7 +159,7 @@ Examples:\n\
   %s -hR staff /u  Change the group of /u and subfiles to \"staff\".\n\
 "),
 	      program_name, program_name);
-      printf (_("\nReport bugs to <%s>.\n"), PACKAGE_BUGREPORT);
+      emit_bug_reporting_address ();
     }
   exit (status);
 }
@@ -260,20 +259,14 @@ main (int argc, char **argv)
 	  if (dereference == 1)
 	    error (EXIT_FAILURE, 0,
 		   _("-R --dereference requires either -H or -L"));
-	  chopt.affect_symlink_referent = false;
-	}
-      else
-	{
-	  if (dereference == 0)
-	    error (EXIT_FAILURE, 0, _("-R -h requires -P"));
-	  chopt.affect_symlink_referent = true;
+	  dereference = 0;
 	}
     }
   else
     {
       bit_flags = FTS_PHYSICAL;
-      chopt.affect_symlink_referent = (dereference != 0);
     }
+  chopt.affect_symlink_referent = (dereference != 0);
 
   if (argc - optind < (reference_file ? 1 : 2))
     {
