@@ -1,10 +1,10 @@
 /* df - summarize free disk space
-   Copyright (C) 91, 1995-2005 Free Software Foundation, Inc.
+   Copyright (C) 91, 1995-2007 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,8 +12,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* Written by David MacKenzie <djm@gnu.ai.mit.edu>.
    --human-readable and --megabyte options added by lm@sgi.com.
@@ -23,11 +22,9 @@
 #include <stdio.h>
 #include <sys/types.h>
 #include <getopt.h>
-#include <assert.h>
 
 #include "system.h"
 #include "canonicalize.h"
-#include "dirname.h"
 #include "error.h"
 #include "fsusage.h"
 #include "human.h"
@@ -69,6 +66,9 @@ static uintmax_t output_block_size;
 /* If true, use the POSIX output format.  */
 static bool posix_format;
 
+/* True if a file system has been processed for output.  */
+static bool file_systems_processed;
+
 /* If true, invoke the `sync' system call before getting any usage data.
    Using this option can make df very slow, especially with many or very
    busy disks.  Note that this may make a difference on some systems --
@@ -114,8 +114,8 @@ static bool print_type;
    non-character as a pseudo short option, starting with CHAR_MAX + 1.  */
 enum
 {
-  SYNC_OPTION = CHAR_MAX + 1,
-  NO_SYNC_OPTION
+  NO_SYNC_OPTION = CHAR_MAX + 1,
+  SYNC_OPTION
 };
 
 static struct option const long_options[] =
@@ -125,7 +125,6 @@ static struct option const long_options[] =
   {"inodes", no_argument, NULL, 'i'},
   {"human-readable", no_argument, NULL, 'h'},
   {"si", no_argument, NULL, 'H'},
-  {"kilobytes", no_argument, NULL, 'k'}, /* long form is obsolescent */
   {"local", no_argument, NULL, 'l'},
   {"megabytes", no_argument, NULL, 'm'}, /* obsolescent */
   {"portability", no_argument, NULL, 'P'},
@@ -159,7 +158,7 @@ print_header (void)
 	printf (_("     Size   Used  Avail Use%%"));
     }
   else if (posix_format)
-    printf (_(" %4s-blocks      Used Available Capacity"),
+    printf (_(" %s-blocks      Used Available Capacity"),
 	    umaxtostr (output_block_size, buf));
   else
     {
@@ -230,15 +229,15 @@ excluded_fstype (const char *fstype)
 /* Like human_readable (N, BUF, human_output_opts, INPUT_UNITS, OUTPUT_UNITS),
    except:
 
-    - Return "-" if N is -1,
-    - If NEGATIVE is 1 then N represents a negative number,
-      expressed in two's complement.  */
+    - If NEGATIVE, then N represents a negative number,
+      expressed in two's complement.
+    - Otherwise, return "-" if N is UINTMAX_MAX.  */
 
 static char const *
 df_readable (bool negative, uintmax_t n, char *buf,
 	     uintmax_t input_units, uintmax_t output_units)
 {
-  if (n == UINTMAX_MAX)
+  if (n == UINTMAX_MAX && !negative)
     return "-";
   else
     {
@@ -271,6 +270,7 @@ show_dev (char const *disk, char const *mount_point,
   struct fs_usage fsu;
   char buf[3][LONGEST_HUMAN_READABLE + 2];
   int width;
+  int col1_adjustment = 0;
   int use_width;
   uintmax_t input_units;
   uintmax_t output_units;
@@ -308,6 +308,12 @@ show_dev (char const *disk, char const *mount_point,
   if (fsu.fsu_blocks == 0 && !show_all_fs && !show_listed_fs)
     return;
 
+  if (! file_systems_processed)
+    {
+      file_systems_processed = true;
+      print_header ();
+    }
+
   if (! disk)
     disk = "-";			/* unknown */
   if (! fstype)
@@ -346,9 +352,19 @@ show_dev (char const *disk, char const *mount_point,
     }
   else
     {
-      width = (human_output_opts & human_autoscale
-	       ? 5 + ! (human_output_opts & human_base_1024)
-	       : 9);
+      if (human_output_opts & human_autoscale)
+	width = 5 + ! (human_output_opts & human_base_1024);
+      else
+	{
+	  width = 9;
+	  if (posix_format)
+	    {
+	      uintmax_t b;
+	      col1_adjustment = -3;
+	      for (b = output_block_size; 9 < b; b /= 10)
+		col1_adjustment++;
+	    }
+	}
       use_width = ((posix_format
 		    && ! (human_output_opts & human_autoscale))
 		   ? 8 : 4);
@@ -356,25 +372,23 @@ show_dev (char const *disk, char const *mount_point,
       output_units = output_block_size;
       total = fsu.fsu_blocks;
       available = fsu.fsu_bavail;
-      negate_available = fsu.fsu_bavail_top_bit_set;
+      negate_available = (fsu.fsu_bavail_top_bit_set
+			  & (available != UINTMAX_MAX));
       available_to_root = fsu.fsu_bfree;
     }
 
-  used = -1;
+  used = UINTMAX_MAX;
   negate_used = false;
   if (total != UINTMAX_MAX && available_to_root != UINTMAX_MAX)
     {
       used = total - available_to_root;
-      if (total < available_to_root)
-	{
-	  negate_used = true;
-	  used = - used;
-	}
+      negate_used = (total < available_to_root);
     }
 
   printf (" %*s %*s %*s ",
-	  width, df_readable (false, total,
-			      buf[0], input_units, output_units),
+	  width + col1_adjustment,
+	  df_readable (false, total,
+		       buf[0], input_units, output_units),
 	  width, df_readable (negate_used, used,
 			      buf[1], input_units, output_units),
 	  width, df_readable (negate_available, available,
@@ -613,8 +627,15 @@ show_point (const char *point, const struct stat *statp)
 	      me->me_dev = disk_stats.st_dev;
 	    else
 	      {
-		error (0, errno, "%s", quote (me->me_mountdir));
-		exit_status = EXIT_FAILURE;
+		/* Report only I/O errors.  Other errors might be
+		   caused by shadowed mount points, which means POINT
+		   can't possibly be on this file system.  */
+		if (errno == EIO)
+		  {
+		    error (0, errno, "%s", quote (me->me_mountdir));
+		    exit_status = EXIT_FAILURE;
+		  }
+
 		/* So we won't try and fail repeatedly. */
 		me->me_dev = (dev_t) -2;
 	      }
@@ -722,8 +743,8 @@ or all file systems by default.\n\
 Mandatory arguments to long options are mandatory for short options too.\n\
 "), stdout);
       fputs (_("\
-  -a, --all             include file systems having 0 blocks\n\
-  -B, --block-size=SIZE use SIZE-byte blocks\n\
+  -a, --all             include dummy file systems\n\
+  -B, --block-size=SIZE  use SIZE-byte blocks\n\
   -h, --human-readable  print sizes in human readable format (e.g., 1K 234M 2G)\n\
   -H, --si              likewise, but use powers of 1000 not 1024\n\
 "), stdout);
@@ -747,7 +768,7 @@ Mandatory arguments to long options are mandatory for short options too.\n\
 SIZE may be (or may be an integer optionally followed by) one of following:\n\
 kB 1000, K 1024, MB 1000*1000, M 1024*1024, and so on for G, T, P, E, Z, Y.\n\
 "), stdout);
-      printf (_("\nReport bugs to <%s>.\n"), PACKAGE_BUGREPORT);
+      emit_bug_reporting_address ();
     }
   exit (status);
 }
@@ -755,9 +776,7 @@ kB 1000, K 1024, MB 1000*1000, M 1024*1024, and so on for G, T, P, E, Z, Y.\n\
 int
 main (int argc, char **argv)
 {
-  int c;
   struct stat *stats IF_LINT (= 0);
-  int n_valid_args = 0;
 
   initialize_main (&argc, &argv);
   program_name = argv[0];
@@ -772,24 +791,32 @@ main (int argc, char **argv)
   inode_format = false;
   show_all_fs = false;
   show_listed_fs = false;
-
-  human_output_opts = human_options (getenv ("DF_BLOCK_SIZE"), false,
-				     &output_block_size);
-
+  human_output_opts = -1;
   print_type = false;
+  file_systems_processed = false;
   posix_format = false;
   exit_status = EXIT_SUCCESS;
 
-  while ((c = getopt_long (argc, argv, "aB:iF:hHklmPTt:vx:", long_options, NULL))
-	 != -1)
+  for (;;)
     {
+      int oi = -1;
+      int c = getopt_long (argc, argv, "aB:iF:hHklmPTt:vx:", long_options,
+			   &oi);
+      if (c == -1)
+	break;
+
       switch (c)
 	{
 	case 'a':
 	  show_all_fs = true;
 	  break;
 	case 'B':
-	  human_output_opts = human_options (optarg, true, &output_block_size);
+	  {
+	    enum strtol_error e = human_options (optarg, &human_output_opts,
+						 &output_block_size);
+	    if (e != LONGINT_OK)
+	      xstrtol_fatal (e, oi, c, long_options, optarg);
+	  }
 	  break;
 	case 'i':
 	  inode_format = true;
@@ -847,6 +874,18 @@ main (int argc, char **argv)
 	}
     }
 
+  if (human_output_opts == -1)
+    {
+      if (posix_format)
+	{
+	  human_output_opts = 0;
+	  output_block_size = (getenv ("POSIXLY_CORRECT") ? 512 : 1024);
+	}
+      else
+	human_options (getenv ("DF_BLOCK_SIZE"),
+		       &human_output_opts, &output_block_size);
+    }
+
   /* Fail if the same file system type was both selected and excluded.  */
   {
     bool match = false;
@@ -885,10 +924,6 @@ main (int argc, char **argv)
 	      exit_status = EXIT_FAILURE;
 	      argv[i] = NULL;
 	    }
-	  else
-	    {
-	      ++n_valid_args;
-	    }
 	}
     }
 
@@ -903,10 +938,10 @@ main (int argc, char **argv)
       /* Couldn't read the table of mounted file systems.
 	 Fail if df was invoked with no file name arguments;
 	 Otherwise, merely give a warning and proceed.  */
+      int status =          (optind < argc ? 0 : EXIT_FAILURE);
       const char *warning = (optind < argc ? _("Warning: ") : "");
-      int status = (optind < argc ? 0 : EXIT_FAILURE);
-      error (status, errno,
-	     _("%scannot read table of mounted file systems"), warning);
+      error (status, errno, "%s%s", warning,
+	     _("cannot read table of mounted file systems"));
     }
 
   if (require_sync)
@@ -919,18 +954,15 @@ main (int argc, char **argv)
       /* Display explicitly requested empty file systems. */
       show_listed_fs = true;
 
-      if (n_valid_args > 0)
-	print_header ();
-
       for (i = optind; i < argc; ++i)
 	if (argv[i])
 	  show_entry (argv[i], &stats[i - optind]);
     }
   else
-    {
-      print_header ();
-      show_all_entries ();
-    }
+    show_all_entries ();
+
+  if (! file_systems_processed)
+    error (EXIT_FAILURE, 0, _("no file systems processed"));
 
   exit (exit_status);
 }
