@@ -29,6 +29,7 @@ static char const G_line[] =
   'T','E','R','M',' ','e','t','e','r','m','-','c','o','l','o','r',0,
   'T','E','R','M',' ','g','n','o','m','e',0,
   'T','E','R','M',' ','g','n','o','m','e','-','2','5','6','c','o','l','o','r',0,
+  'T','E','R','M',' ','j','f','b','t','e','r','m',0,
   'T','E','R','M',' ','k','o','n','s','o','l','e',0,
   'T','E','R','M',' ','k','t','e','r','m',0,
   'T','E','R','M',' ','l','i','n','u','x',0,
@@ -60,8 +61,9 @@ static char const G_line[] =
   '#',' ','3','0','=','b','l','a','c','k',' ','3','1','=','r','e','d',' ','3','2','=','g','r','e','e','n',' ','3','3','=','y','e','l','l','o','w',' ','3','4','=','b','l','u','e',' ','3','5','=','m','a','g','e','n','t','a',' ','3','6','=','c','y','a','n',' ','3','7','=','w','h','i','t','e',0,
   '#',' ','B','a','c','k','g','r','o','u','n','d',' ','c','o','l','o','r',' ','c','o','d','e','s',':',0,
   '#',' ','4','0','=','b','l','a','c','k',' ','4','1','=','r','e','d',' ','4','2','=','g','r','e','e','n',' ','4','3','=','y','e','l','l','o','w',' ','4','4','=','b','l','u','e',' ','4','5','=','m','a','g','e','n','t','a',' ','4','6','=','c','y','a','n',' ','4','7','=','w','h','i','t','e',0,
-  'N','O','R','M','A','L',' ','0','0',' ','#',' ','g','l','o','b','a','l',' ','d','e','f','a','u','l','t',',',' ','a','l','t','h','o','u','g','h',' ','e','v','e','r','y','t','h','i','n','g',' ','s','h','o','u','l','d',' ','b','e',' ','s','o','m','e','t','h','i','n','g','.',0,
-  'F','I','L','E',' ','0','0',' ','#',' ','n','o','r','m','a','l',' ','f','i','l','e',0,
+  '#','N','O','R','M','A','L',' ','0','0',' ','#',' ','n','o',' ','c','o','l','o','r',' ','c','o','d','e',' ','a','t',' ','a','l','l',0,
+  '#','F','I','L','E',' ','0','0',' ','#',' ','r','e','g','u','l','a','r',' ','f','i','l','e',':',' ','u','s','e',' ','n','o',' ','c','o','l','o','r',' ','a','t',' ','a','l','l',0,
+  'R','E','S','E','T',' ','0',' ','#',' ','r','e','s','e','t',' ','t','o',' ','"','n','o','r','m','a','l','"',' ','c','o','l','o','r',0,
   'D','I','R',' ','0','1',';','3','4',' ','#',' ','d','i','r','e','c','t','o','r','y',0,
   'L','I','N','K',' ','0','1',';','3','6',' ','#',' ','s','y','m','b','o','l','i','c',' ','l','i','n','k','.',' ','(','I','f',' ','y','o','u',' ','s','e','t',' ','t','h','i','s',' ','t','o',' ','\'','t','a','r','g','e','t','\'',' ','i','n','s','t','e','a','d',' ','o','f',' ','a',0,
   ' ','#',' ','n','u','m','e','r','i','c','a','l',' ','v','a','l','u','e',',',' ','t','h','e',' ','c','o','l','o','r',' ','i','s',' ','a','s',' ','f','o','r',' ','t','h','e',' ','f','i','l','e',' ','p','o','i','n','t','e','d',' ','t','o','.',')',0,
@@ -94,7 +96,6 @@ static char const G_line[] =
   ' ','#',' ','a','r','c','h','i','v','e','s',' ','o','r',' ','c','o','m','p','r','e','s','s','e','d',' ','(','b','r','i','g','h','t',' ','r','e','d',')',0,
   '.','t','a','r',' ','0','1',';','3','1',0,
   '.','t','g','z',' ','0','1',';','3','1',0,
-  '.','s','v','g','z',' ','0','1',';','3','1',0,
   '.','a','r','j',' ','0','1',';','3','1',0,
   '.','t','a','z',' ','0','1',';','3','1',0,
   '.','l','z','h',' ','0','1',';','3','1',0,
@@ -132,6 +133,7 @@ static char const G_line[] =
   '.','t','i','f','f',' ','0','1',';','3','5',0,
   '.','p','n','g',' ','0','1',';','3','5',0,
   '.','s','v','g',' ','0','1',';','3','5',0,
+  '.','s','v','g','z',' ','0','1',';','3','5',0,
   '.','m','n','g',' ','0','1',';','3','5',0,
   '.','p','c','x',' ','0','1',';','3','5',0,
   '.','m','o','v',' ','0','1',';','3','5',0,
@@ -153,6 +155,7 @@ static char const G_line[] =
   '.','f','l','c',' ','0','1',';','3','5',0,
   '.','a','v','i',' ','0','1',';','3','5',0,
   '.','f','l','i',' ','0','1',';','3','5',0,
+  '.','f','l','v',' ','0','1',';','3','5',0,
   '.','g','l',' ','0','1',';','3','5',0,
   '.','d','l',' ','0','1',';','3','5',0,
   '.','x','c','f',' ','0','1',';','3','5',0,
