@@ -1,10 +1,10 @@
 /* GNU fmt -- simple text formatter.
-   Copyright (C) 1994-2005 Free Software Foundation, Inc.
+   Copyright (C) 1994-2006 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,8 +12,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* Written by Ross Paterson <rap@doc.ic.ac.uk>.  */
 
@@ -297,7 +296,7 @@ Mandatory arguments to long options are mandatory for short options too.\n\
 \n\
 With no FILE, or when FILE is -, read standard input.\n"),
 	     stdout);
-      printf (_("\nReport bugs to <%s>.\n"), PACKAGE_BUGREPORT);
+      emit_bug_reporting_address ();
     }
   exit (status);
 }
@@ -607,12 +606,15 @@ copy_rest (FILE *f, int c)
   const char *s;
 
   out_column = 0;
-  if (in_column > next_prefix_indent && c != '\n' && c != EOF)
+  if (in_column > next_prefix_indent || (c != '\n' && c != EOF))
     {
       put_space (next_prefix_indent);
       for (s = prefix; out_column != in_column && *s; out_column++)
 	putchar (*s++);
-      put_space (in_column - out_column);
+      if (c != EOF && c != '\n')
+	put_space (in_column - out_column);
+      if (c == EOF && in_column >= next_prefix_indent + prefix_length)
+	putchar ('\n');
     }
   while (c != '\n' && c != EOF)
     {
@@ -668,7 +670,7 @@ get_line (FILE *f, int c)
 	  *wptr++ = c;
 	  c = getc (f);
 	}
-      while (c != EOF && !ISSPACE (c));
+      while (c != EOF && !isspace (c));
       in_column += word_limit->length = wptr - word_limit->text;
       check_punctuation (word_limit);
 
@@ -688,10 +690,8 @@ get_line (FILE *f, int c)
 	  flush_paragraph ();
 	}
       word_limit++;
-      if (c == EOF)
-	return EOF;
     }
-  while (c != '\n');
+  while (c != '\n' && c != EOF);
   return get_prefix (f);
 }
 
@@ -756,7 +756,7 @@ check_punctuation (WORD *w)
   unsigned char fin = *finish;
 
   w->paren = isopen (*start);
-  w->punct = ISPUNCT (fin);
+  w->punct = !! ispunct (fin);
   while (start < finish && isclose (*finish))
     finish--;
   w->period = isperiod (*finish);
