@@ -1,5 +1,5 @@
 /* pr -- convert text files for printing.
-   Copyright (C) 88, 91, 1995-2007 Free Software Foundation, Inc.
+   Copyright (C) 88, 91, 1995-2008 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -315,7 +315,6 @@
 #include "system.h"
 #include "error.h"
 #include "hard-locale.h"
-#include "inttostr.h"
 #include "mbswidth.h"
 #include "quote.h"
 #include "stat-time.h"
@@ -2727,7 +2726,17 @@ char_to_clump (char c)
       *s = c;
     }
 
-  input_position += width;
+  /* Too many backspaces must put us in position 0 -- never negative.  */
+  if (width < 0 && input_position == 0)
+    {
+      chars = 0;
+      input_position = 0;
+    }
+  else if (width < 0 && input_position <= -width)
+    input_position = 0;
+  else
+    input_position += width;
+
   return chars;
 }
 
