@@ -1,10 +1,10 @@
 /* GNU's who.
-   Copyright (C) 1992-2006 Free Software Foundation, Inc.
+   Copyright (C) 1992-2007 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,8 +12,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* Written by jla; revised by djm; revised again by mstone */
 
@@ -37,7 +36,6 @@
 #include "hard-locale.h"
 #include "inttostr.h"
 #include "quote.h"
-#include "vasprintf.h"
 
 /* The official name of this program (e.g., no `g' prefix).  */
 #define PROGRAM_NAME "who"
@@ -78,7 +76,7 @@
 # define UT_TYPE_NEW_TIME(U) false
 #endif
 
-#define IDLESTR_LEN 10
+#define IDLESTR_LEN 6
 
 #if HAVE_STRUCT_XTMP_UT_PID
 # define PIDSTR_DECL_AND_INIT(Var, Utmp_ent) \
@@ -167,7 +165,6 @@ static struct option const longopts[] = {
   {"count", no_argument, NULL, 'q'},
   {"dead", no_argument, NULL, 'd'},
   {"heading", no_argument, NULL, 'H'},
-  {"idle", no_argument, NULL, 'i'}, /* FIXME: deprecated: remove in late 2006 */
   {"login", no_argument, NULL, 'l'},
   {"lookup", no_argument, NULL, LOOKUP_OPTION},
   {"message", no_argument, NULL, 'T'},
@@ -665,7 +662,7 @@ usage (int status)
 If FILE is not specified, use %s.  %s as FILE is common.\n\
 If ARG1 ARG2 given, -m presumed: `am i' or `mom likes' are usual.\n\
 "), UTMP_FILE, WTMP_FILE);
-      printf (_("\nReport bugs to <%s>.\n"), PACKAGE_BUGREPORT);
+      emit_bug_reporting_address ();
     }
   exit (status);
 }
@@ -684,7 +681,7 @@ main (int argc, char **argv)
 
   atexit (close_stdout);
 
-  while ((optc = getopt_long (argc, argv, "abdilmpqrstuwHT", longopts, NULL))
+  while ((optc = getopt_long (argc, argv, "abdlmpqrstuwHT", longopts, NULL))
 	 != -1)
     {
       switch (optc)
@@ -758,11 +755,6 @@ main (int argc, char **argv)
 	  include_mesg = true;
 	  break;
 
-	case 'i':
-	  error (0, 0,
-		 _("Warning: -i will be removed in a future release; \
-  use -u instead"));
-	  /* Fall through.  */
 	case 'u':
 	  need_users = true;
 	  include_idle = true;
